#
# spec file for package fcitx5-rime
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fcitx5-rime
Version:        5.1.4
Release:        1.1
Summary:        RIME support for Fcitx5
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/fcitx/fcitx5-rime
Source:         https://download.fcitx-im.org/fcitx5/%{name}/%{name}-%{version}.tar.xz
Patch0:         %{name}-cmake-3.10.patch
BuildRequires:  brise
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx5-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  librime-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
Requires:       fcitx5
Requires:       rime
Provides:       fcitx-rime = %{version}
Obsoletes:      fcitx-rime <= 0.3.2
%if 0%{?suse_version} <= 1520
BuildRequires:  appstream-glib-devel
%endif

%description
This package provides RIME support for Fcitx5.

%prep
%setup -q
%patch -P 0 -p1

%build
%cmake
%make_build

%install
%cmake_install
%find_lang %{name}

%files -f %{name}.lang
%doc README.md
%license LICENSES
%dir %{_datadir}/fcitx5/inputmethod
%{_libdir}/fcitx5/librime.so
%{_datadir}/fcitx5/addon/rime.conf
%{_datadir}/fcitx5/inputmethod/rime.conf
%{_datadir}/icons/hicolor/*/apps/fcitx-rime*
%{_datadir}/icons/hicolor/*/apps/fcitx_rime_*
%{_datadir}/icons/hicolor/*/apps/org.fcitx.Fcitx5.fcitx-rime*
%{_datadir}/icons/hicolor/*/apps/org.fcitx.Fcitx5.fcitx_rime_*
%{_datadir}/metainfo/org.fcitx.Fcitx5.Addon.Rime.metainfo.xml
%{_datadir}/rime-data/fcitx5.yaml

%changelog
* Mon Feb  5 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.4
  * follow preedit cursor position option in commit preview
  * rename all rime action icon to avoid wrong icon being used
  * don't use rime-im icon so we can see the label on kimpanel
  * implement same preedit mode option like pinyin
  * only clear saved state when fill a new session to the state
  * always clear the saved state after request session
  * do not unregister factory since the state will store the snap-
    shotted value
  * snapshot the state in deploy and reloadConfig
  * set timeout to non-default value
  * implement option's save and restore
- changes in 5.1.3
  * Show rime option in status area
  * support virtual keyboard candidate list better
  * add an option to control how the rime state is shared, default
    behavior is changed to share in all clients.
  * Restore rime schema / option when saving.
* Tue Oct  3 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.2
  * Fix more than 10 candidate per page
* Sun Aug 20 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.1
  * recreate all rime sessions when auto saving data
  * rime session now follows the global shared state option.
* Mon May 22 2023 Marguerite Su <i@marguerite.su>
- Update to 5.0.16
  * update wording for punctuation
* Sun Nov 20 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.15
  * fixes some memory leaks
- Remove obsolete patch, since Leap 15.3 already has newer CMake
  * fcitx5-rime-cmake-3.10.patch
* Tue Jul  5 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.14
  * Status change notification now uses its own notification id, so you
    can hide them individually. Previously they were using the same id of
    the notification of deployment.
* Sat Mar 12 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.12
  * Show notification for option change
* Sat Feb 12 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.11
  * Show option change in notification.
* Tue Jan 25 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.10
  * weasel / squirrel style app_options support
* Wed Dec 15 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.9
  * Support fix cursor at beginning of the text
* Sat Nov  6 2021 J <hj@powersnail.com>
- update to version 5.0.8
  * Add a dbus service to access the rime schema and set the rime state.
* Wed May  5 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.6
  * rime 1.7.0 would load rime plugin by itself,
    do not do the plugin loading in our code when
    1.7.0 is used.
- changes in version 5.0.5
  * Implement sub mode label
  * show information when mode changes.
* Tue Mar 16 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.4
  * Display sub mode if it is under "Latin mode", this should
    help to avoid confusion when rime enter latin mode for
    certain key bindings.
* Wed Jan 20 2021 Dingzhong Chen <wsxy162@gmail.com>
- update version 5.0.3
- Remove Requires: brise, since it has been deprecated upstream
  and already recommended by librime
* Sun Dec  6 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.1
* Tue Nov 10 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.0
* Mon Oct 19 2020 emricg2@gmail.com
- Update to version 0.0.0+git20200913.e20996d
* Fri Sep  4 2020 Marguerite Su <i@marguerite.su>
- update version 0.0.0+git20200615.e4fc600
* Tue Mar  3 2020 Xu Zhao <i@xuzhao.net>
- update to git20200212.72a9df7
* Sun Sep 16 2018 i@marguerite.su
- initial package
